pub trait PatternReplaceMany {
// Required methods
fn pattern_replace_pairs(
&self,
replacement_sets: &[(&str, &str)],
case_insensitive: bool,
) -> Self
where Self: Sized;
fn pattern_replace_sets(
&self,
replacement_sets: &[(&str, &str, bool)],
) -> Self
where Self: Sized;
// Provided methods
fn pattern_replace_pairs_ci(
&self,
replacement_sets: &[(&str, &str)],
) -> Self
where Self: Sized { ... }
fn pattern_replace_pairs_cs(
&self,
replacement_sets: &[(&str, &str)],
) -> Self
where Self: Sized { ... }
}Expand description
Provides methods to replace with multiple patterns expressed as arrays of tuples
Required Methods
Provided Methods
Sourcefn pattern_replace_pairs_ci(&self, replacement_sets: &[(&str, &str)]) -> Selfwhere
Self: Sized,
fn pattern_replace_pairs_ci(&self, replacement_sets: &[(&str, &str)]) -> Selfwhere
Self: Sized,
Replaces multiple sets of patterns with replacements in case-insensitive mode with an array of tuples (pattern, replacement, case_insensitive)
Sourcefn pattern_replace_pairs_cs(&self, replacement_sets: &[(&str, &str)]) -> Selfwhere
Self: Sized,
fn pattern_replace_pairs_cs(&self, replacement_sets: &[(&str, &str)]) -> Selfwhere
Self: Sized,
Replaces multiple sets of patterns with replacements in case-insensitive mode with an array of tuples (pattern, replacement, case_insensitive)
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl PatternReplaceMany for String
impl PatternReplaceMany for String
Sourceimpl PatternReplaceMany for Vec<String>
ReplaceMany implementation for vectors of owned strings
impl PatternReplaceMany for Vec<String>
ReplaceMany implementation for vectors of owned strings